Method for extracting model fitted values and detection probabilities from a fitted single-species spatially-varying coefficients occupancy (svcPGOcc) model.
# S3 method for svcPGOcc
fitted(object, ...)A list comprised of:
A three-dimensional numeric array of fitted values for use in Goodness of Fit assessments. Array dimensions correspond to MCMC samples, sites, and replicates.
A three-dimensional numeric array of detection probability values. Array dimensions correspond to MCMC samples, sites, and replicates.
object of class svcPGOcc.
currently no additional arguments
A method to the generic fitted function to extract fitted values and detection probabilities for fitted model objects of class svcPGOcc.